@@ -5,6 +5,7 @@ A Client for interfacing with Twilio
 import os
 from twilio.rest import Client
 
+
 class TwilioClient(object):
 
     def __init__(self, account_sid, auth_token, account_phone):
@@ -18,10 +19,8 @@ class TwilioClient(object):
     # Twilio API
     ##########################
 
-    def text(self, to_number, text_body):
+    def send_text(self, to_number, text_body):
         return self.client.messages.create(
-                from_=self.account_phone,
-                to=to_number,
-                body=text_body)
-
-
+            from_=self.account_phone,
+            to=to_number,
+            body=text_body)
