@@ -11,11 +11,10 @@ from multiprocessing import Pool, Lock
 # ===================================
 #
 
-def multiProcess(fn, iterable, num_threads, pbar=False, desc=None):
+def map_multiprocess(fn, iterable, num_threads, pbar=False, desc=None):
     iterable = tqdm(iterable, desc=desc) if pbar else iterable
     pool = Pool(num_threads)
     res = pool.map(fn, iterable)
     pool.close()
-    pool.join() 
+    pool.join()
     return res
-
