@@ -4,7 +4,11 @@ URL helpers
 
 import requests
 
-def fixURL(url):
+
+def fix_url(url):
+    """
+    .. todo:: fixes more cases
+    """
     assert type(url) == str, "URL has to be a string"
     if url.startswith("www."):
         url = "http://{}".format(url)
@@ -12,6 +16,8 @@ def fixURL(url):
 
 
 def request(url, params=None):
-    url = fixURL(url)
+    """
+    .. todo:: use params as necessary
+    """
+    url = fix_url(url)
     return requests.get(url).content
-
